# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['document_merge_service',
 'document_merge_service.api',
 'document_merge_service.api.data',
 'document_merge_service.api.management',
 'document_merge_service.api.management.commands',
 'document_merge_service.api.migrations',
 'document_merge_service.api.tests',
 'document_merge_service.api.tests.snapshots',
 'document_merge_service.tests']

package_data = \
{'': ['*'], 'document_merge_service.api.data': ['loadtest/*']}

install_requires = \
['Babel>=2.11.0,<3.0.0',
 'Django>=3.2.16,<4.0.0',
 'Jinja2>=3.1.2,<4.0.0',
 'django-cors-headers>=3.13.0,<4.0.0',
 'django-environ>=0.9.0,<0.10.0',
 'django-filter>=22.1,<23.0',
 'django-generic-api-permissions>=0.2.0,<0.3.0',
 'djangorestframework>=3.14.0,<4.0.0',
 'docx-mailmerge>=0.5.0,<0.6.0',
 'docxtpl>=0.16.4,<0.17.0',
 'openpyxl>=3.0.10,<4.0.0',
 'python-dateutil>=2.8.2,<3.0.0',
 'python-memcached>=1.59,<2.0',
 'requests>=2.28.1,<3.0.0',
 'uWSGI>=2.0.21,<3.0.0',
 'xltpl>=0.16,<0.17']

extras_require = \
{'databases': ['mysqlclient>=2.1.1,<3.0.0', 'psycopg2-binary>=2.9.5,<3.0.0'],
 'mysql': ['mysqlclient>=2.1.1,<3.0.0'],
 'pgsql': ['psycopg2-binary>=2.9.5,<3.0.0']}

setup_kwargs = {
    'name': 'document-merge-service',
    'version': '5.2.1',
    'description': 'Merge Document Template Service',
    'long_description': '# Document Merge Service\n\n[![Build Status](https://github.com/adfinis/document-merge-service/actions/workflows/tests.yml/badge.svg)](https://github.com/adfinis/document-merge-service/actions/workflows/tests.yml)\n[![Black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/adfinis/document-merge-service)\n[![License: GPL-3.0-or-later](https://img.shields.io/github/license/adfinis/document-merge-service)](https://spdx.org/licenses/GPL-3.0-or-later.html)\n\nA document template merge service providing an API to manage templates and merge them with given data.\n\n## Installation\n\n**Requirements**\n* docker\n* docker-compose\n\nAfter installing and configuring those, download [docker-compose.yml](https://raw.githubusercontent.com/adfinis/document-merge-service/master/docker-compose.yml) and run the following command:\n\n```bash\ndocker-compose up -d\n```\n\nYou can now access the api at [http://localhost:8000/api/v1/](http://localhost:8000/api/v1/) which includes a browsable api.\n\n### Workaround LibreOffice lockup\n\nThe workaround has a setting called ISOLATE_UNOCONV, it is only enabled in the\ndevelopment environment. If ISOLATE_UNOCONV is enabled the container needs\nCAP_SYS_ADMIN. See docker-compose.override.yml.\n\n```yaml\n    cap_add:\n      - CAP_SYS_ADMIN\n    security_opt:\n      - apparmor:unconfined\n    environment:\n      - ISOLATE_UNOCONV=true\n```\n\n## Getting started\n\n### Uploading templates\n\nUpload templates using the following:\n\n```bash\ncurl --form template=@docx-template.docx --form name="Test Template" --form engine=docx-template http://localhost:8000/api/v1/template/\n```\n\n### Merging a template\n\nAfter uploading successfully, you can merge a template with the following call:\n\n```bash\ncurl -H "Content-Type: application/json" --data \'{"data": {"test": "Test Input"}}\' http://localhost:8000/api/v1/template/test-template/merge/ > output.docx\n```\n\n\n## Further reading\n\n* [Configuration](CONFIGURATION.md) - Further configuration and how to do a production setup\n* [Usage](USAGE.md) - How to use the DMS and it\'s features\n* [Contributing](CONTRIBUTING.md) - Look here to see how to start with your first\n  contribution. Contributions are welcome!\n\n## License\n\nCode released under the [GPL-3.0-or-later license](LICENSE).\n',
    'author': 'Adfinis AG',
    'author_email': 'info@adfinis.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/adfinis/document-merge-service',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
